# Adding custom serialization and deserialization

This example shows how to extend serialization/deserialization of fields in state.

## Prerequisites
``sh
pip install -r requirements.txt
``

## Running the demo
``sh
python application.py
``
or
``
pip install jupyter
jupyter notebook
``
and running the notebook. Or open the notebook <a target="_blank" href="https://colab.research.google.com/github/dagworks-inc/burr/blob/main/examples/custom-serde/notebook.ipynb">
  <img src="https://colab.research.google.com/assets/colab-badge.svg" alt="Open In Colab"/>
</a>

## Explanation
See the notebook and/or `application.py` for more information.
